# flake8: noqa

"""
    EMIL Number Generator Service

    The EMIL Number Generator Service API is a robust tool                  designed to generate unique and structured entity numbers                  like policies, accounts, invoices, and other entities.                  This API streamlines the process of creating distinct identifiers                  for various business objects.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.2.0"

# import ApiClient
from eis.numbergenerator.api_client import ApiClient

# import Configuration
from eis.numbergenerator.configuration import Configuration

# import exceptions
from eis.numbergenerator.exceptions import OpenApiException
from eis.numbergenerator.exceptions import ApiAttributeError
from eis.numbergenerator.exceptions import ApiTypeError
from eis.numbergenerator.exceptions import ApiValueError
from eis.numbergenerator.exceptions import ApiKeyError
from eis.numbergenerator.exceptions import ApiException



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from eis.numbergenerator.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from eis.numbergenerator.model.create_number_response_class import CreateNumberResponseClass
from eis.numbergenerator.model.entity_number_class import EntityNumberClass
from eis.numbergenerator.model.get_number_response_class import GetNumberResponseClass
from eis.numbergenerator.model.inline_response200 import InlineResponse200
from eis.numbergenerator.model.inline_response503 import InlineResponse503
from eis.numbergenerator.model.list_numbers_response_class import ListNumbersResponseClass
from eis.numbergenerator.model.lookup_number_request_dto import LookupNumberRequestDto
from eis.numbergenerator.model.reset_number_request_dto import ResetNumberRequestDto
from eis.numbergenerator.model.update_number_response_class import UpdateNumberResponseClass



"""
    EMIL Number Generator Service

    The EMIL Number Generator Service API is a robust tool                  designed to generate unique and structured entity numbers                  like policies, accounts, invoices, and other entities.                  This API streamlines the process of creating distinct identifiers                  for various business objects.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.numbergenerator
from eis.numbergenerator.model.entity_number_class import EntityNumberClass


class TestEntityNumberClass(unittest.TestCase):
    """EntityNumberClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEntityNumberClass(self):
        """Test EntityNumberClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EntityNumberClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL Number Generator Service

    The EMIL Number Generator Service API is a robust tool                  designed to generate unique and structured entity numbers                  like policies, accounts, invoices, and other entities.                  This API streamlines the process of creating distinct identifiers                  for various business objects.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.numbergenerator
from eis.numbergenerator.api.numbers_api import NumbersApi  # noqa: E501


class TestNumbersApi(unittest.TestCase):
    """NumbersApi unit test stubs"""

    def setUp(self):
        self.api = NumbersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_number(self):
        """Test case for create_number

        Create the number  # noqa: E501
        """
        pass

    def test_get_number(self):
        """Test case for get_number

        Retrieve the number  # noqa: E501
        """
        pass

    def test_list_numbers(self):
        """Test case for list_numbers

        List Numbers  # noqa: E501
        """
        pass

    def test_lookup_number(self):
        """Test case for lookup_number

        Lookup entity number  # noqa: E501
        """
        pass

    def test_reset_number(self):
        """Test case for reset_number

        Reset entity number  # noqa: E501
        """
        pass

    def test_update_number(self):
        """Test case for update_number

        Update the number  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
